summaryrefslogtreecommitdiff
path: root/sys/uvm
diff options
context:
space:
mode:
authorPhilip Guenther <guenther@cvs.openbsd.org>2016-11-07 00:26:34 +0000
committerPhilip Guenther <guenther@cvs.openbsd.org>2016-11-07 00:26:34 +0000
commitbd87d530432bb59e0e8e9945eb3552c2580af213 (patch)
tree094ceb36ef2db9352c5687de586c5176477f3c21 /sys/uvm
parent174c1a4b3e7ca128b5540d3419d42f4d056e96af (diff)
Split PID from TID, giving processes a PID unrelated to the TID of their
initial thread ok jsing@ kettenis@
Diffstat (limited to 'sys/uvm')
-rw-r--r--sys/uvm/uvm_map.c4
-rw-r--r--sys/uvm/uvm_page.c8
-rw-r--r--sys/uvm/uvm_page.h4
3 files changed, 8 insertions, 8 deletions
diff --git a/sys/uvm/uvm_map.c b/sys/uvm/uvm_map.c
index 7b3a51cd1af..10a9ab0601a 100644
--- a/sys/uvm/uvm_map.c
+++ b/sys/uvm/uvm_map.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: uvm_map.c,v 1.225 2016/09/16 02:35:42 dlg Exp $ */
+/* $OpenBSD: uvm_map.c,v 1.226 2016/11/07 00:26:33 guenther Exp $ */
/* $NetBSD: uvm_map.c,v 1.86 2000/11/27 08:40:03 chs Exp $ */
/*
@@ -2951,7 +2951,7 @@ uvm_page_printit(pg, full, pr)
pg->uobject, pg->uanon, (long long)pg->offset);
#if defined(UVM_PAGE_TRKOWN)
if (pg->pg_flags & PG_BUSY)
- (*pr)(" owning process = %d, tag=%s",
+ (*pr)(" owning thread = %d, tag=%s",
pg->owner, pg->owner_tag);
else
(*pr)(" page not busy, no owner");
diff --git a/sys/uvm/uvm_page.h b/sys/uvm/uvm_page.h
index ca1fc255d3c..6ea58655b01 100644
--- a/sys/uvm/uvm_page.h
+++ b/sys/uvm/uvm_page.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: uvm_page.h,v 1.62 2016/09/16 02:35:42 dlg Exp $ */
+/* $OpenBSD: uvm_page.h,v 1.63 2016/11/07 00:26:33 guenther Exp $ */
/* $NetBSD: uvm_page.h,v 1.19 2000/12/28 08:24:55 chs Exp $ */
/*
@@ -112,7 +112,7 @@ struct vm_page {
#if defined(UVM_PAGE_TRKOWN)
/* debugging fields to track page ownership */
- pid_t owner; /* proc that set PG_BUSY */
+ pid_t owner; /* thread that set PG_BUSY */
char *owner_tag; /* why it was set busy */
#endif
};
diff --git a/sys/uvm/uvm_page.c b/sys/uvm/uvm_page.c
index 24a150c859f..4002c61dfad 100644
--- a/sys/uvm/uvm_page.c
+++ b/sys/uvm/uvm_page.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: uvm_page.c,v 1.145 2016/09/16 02:35:42 dlg Exp $ */
+/* $OpenBSD: uvm_page.c,v 1.146 2016/11/07 00:26:33 guenther Exp $ */
/* $NetBSD: uvm_page.c,v 1.44 2000/11/27 08:40:04 chs Exp $ */
/*
@@ -1077,7 +1077,7 @@ uvm_page_unbusy(struct vm_page **pgs, int npgs)
*
* => this is a debugging function that keeps track of who sets PG_BUSY
* and where they do it. it can be used to track down problems
* such a process setting "PG_BUSY" and never releasing it.
* => if "tag" is NULL then we are releasing page ownership
*/
void
@@ -1087,11 +1087,11 @@ uvm_page_own(struct vm_page *pg, char *tag)
if (tag) {
if (pg->owner_tag) {
printf("uvm_page_own: page %p already owned "
- "by proc %d [%s]\n", pg,
+ "by thread %d [%s]\n", pg,
pg->owner, pg->owner_tag);
panic("uvm_page_own");
}
- pg->owner = (curproc) ? curproc->p_pid : (pid_t) -1;
+ pg->owner = (curproc) ? curproc->p_tid : (pid_t) -1;
pg->owner_tag = tag;
return;
}
@@ -1077,7 +1077,7 @@ uvm_page_unbusy(struct vm_page **pgs, int npgs)
* => this is a debugging function that keeps track of who sets PG_BUSY
* and where they do it. it can be used to track down problems
- * such a process setting "PG_BUSY" and never releasing it.
+ * such a thread setting "PG_BUSY" and never releasing it.
* => if "tag" is NULL then we are releasing page ownership
*/